- chrom
(character) name of chromesome, including chr1-chr22, chrX.
- pos_lower
(integer) lower base pair location threshold, expressed as an integer
- pos_upper
(integer) upper base pair location threshold, expressed as an integer
- p_lower
(numeric) lower p-value threshold, can be expressed as a float or using mantissa and exponent annotation (0.001 or 1e-3 or 1E-3)
- p_upper
(numeric) upper p-value threshold, can be expressed as a float or using mantissa and exponent annotation (0.001 or 1e-3 or 1E-3)
- gene
(character) gene symbol or gencode id (versioned or unversioned are both supported).
- geneType
(character) options: "auto","geneSymbol" or "gencodeId". Default: "auto".
- tissueLabel
(character) all supported tissues can be listed using "ebi_study_tissues".
- study
(character) name of studies can be listed using "ebi_study_tissues".
- recordPerChunk
(integer) number of records fetched per request (default: 1000).
- withB37VariantId
a logical value indicating whether to return the genome location(GTEx v7) of variants. Default: FALSE.