Learn R Programming

xQTLbiolinks (version 1.6.2)

xQTLvisual_geneExpTissues: Violin plot of distribution of the gene expression profiles among multiple tissues.

Description

Violin plot of distribution of the gene expression profiles among multiple tissues.

Usage

xQTLvisual_geneExpTissues(
  gene = "",
  geneType = "auto",
  tissues = "All",
  log10y = FALSE,
  toTissueSite = FALSE
)

Value

A list containing expression profile and a ggplot object.

Arguments

gene

(character) gene symbol or gencode id (versioned or unversioned are both supported).

geneType

(character) options: "auto","geneSymbol" or "gencodeId". Default: "auto".

tissues

A character string or a vector. "All" (default) means that all tissues is included.

log10y

Display values of expression in log scale. Default: FALSE.

toTissueSite

TRUE or FALSE, display all subtissues or tissue Site. Default: TURE.

Examples

Run this code
# \donttest{
# Display gene expression in specified tissues.
geneExpTissues <- xQTLvisual_geneExpTissues("TP53", tissues=c("Lung", "Brain","Ovary"))
# }

Run the code above in your browser using DataLab