Learn R Programming

xQTLbiolinks (version 1.6.2)

xQTLvisual_sqtl: Box plot with jittered points for showing number and significance of sQTL associations

Description

Box plot with jittered points for showing number and significance of sQTL associations

Usage

xQTLvisual_sqtl(gene, geneType = "auto")

Value

A ggplot object.

Arguments

gene

(character) gene symbol or gencode id (versioned or unversioned are both supported).

geneType

(character) options: "auto","geneSymbol" or "gencodeId". Default: "auto".

Examples

Run this code
# \donttest{
xQTLvisual_sqtl("KIF15")
# }

Run the code above in your browser using DataLab